Analysis Modules
================

Protocol analysis modules provide the core functionality for parsing and analyzing different network protocols.

Base Module
-----------

.. automodule:: mcpcap.modules.base
   :members:
   :undoc-members:
   :show-inheritance:

DNS Module
----------

.. automodule:: mcpcap.modules.dns
   :members:
   :undoc-members:
   :show-inheritance:

DHCP Module
-----------

.. automodule:: mcpcap.modules.dhcp
   :members:
   :undoc-members:
   :show-inheritance:

ICMP Module
-----------

.. automodule:: mcpcap.modules.icmp
   :members:
   :undoc-members:
   :show-inheritance:

TCP Module
----------

.. automodule:: mcpcap.modules.tcp
   :members:
   :undoc-members:
   :show-inheritance:

CapInfos Module
---------------

.. automodule:: mcpcap.modules.capinfos
   :members:
   :undoc-members:
   :show-inheritance:
